/*
* ==============================================================================
*  Name        : CMetadataEntry.h
*  Part of     : Shoutcast Engine
*  Interface   :
*  Description : Defines shoutcast engine metadata entry class
*  Version     : 1
*
*  Copyright (c) 2006, Nokia Corporation All rights reserved. Redistribution
*  and use in source and binary forms, with or without modification, are
*  permitted provided that the following conditions are met: Redistributions
*  of source code must retain the above copyright notice, this list of
*  conditions and the following disclaimer. Redistributions in binary form
*  must reproduce the above copyright notice, this list of conditions and the
*  following disclaimer in the documentation and/or other materials provided
*  with the distribution. Neither the name of the Nokia Corporation nor the
*  names of its contributors may be used to endorse or promote products
*  derived from this software without specific prior written permission. THIS
*  SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
*  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
*  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
*  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
*  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
*  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
*  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
*  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
*  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
*  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
*  POSSIBILITY OF SUCH DAMAGE.
* ==============================================================================
*/

#ifndef __CMETADTAENTRY_H
#define __CMETADTAENTRY_H

#include <e32std.h>
#include <e32base.h>

class CMetaDataEntry : public CBase
	{
	public:

		/**
		* Constructs a new meta data object using a name and value.
		* @param aName The name, or category, to be given to this piece of meta data.
		* @param aValue The value of this piece of meta data.
		* @return Metadata object
		*/
		static CMetaDataEntry* NewL(const TDesC& aName, const TDesC& aValue);

		/**
		* Construct a new meta data object using another meta data object
		* @param aMetadata The meta data to be copied.
		* @return Metadata object
		*/
		static CMetaDataEntry* NewL(const CMetaDataEntry& aMetadata);

		/**
		* Destructor.
		*/
		~CMetaDataEntry();

		/**
		* Get the name, or category, of the meta data
		* @return The name of the meta data object.
		*/
		const TDesC& Name() const;

		/**
		* Get the value field of the meta data.
		* @return The value field of the meta data object.
		*/
		const TDesC& Value() const;

		/**
		* Sets the name, or category, of the meta data.
		* @param aName The new name of the meta data object
		*/
		void SetNameL(const TDesC& aName);

		/**
		* Sets the value field of the meta data.
		* @param  aValue The new value field of the meta data object
		*/
		void SetValueL(const TDesC& aValue);

	private:

        /**
        * C++ default constructor.
		*/
		CMetaDataEntry();

		/**
		* By default Symbian 2nd phase constructor is private.
		* @param aName The name, or category, to be given to this piece of meta data.
		* @param aValue The value of this piece of meta data.
		*/
		void ConstructL(const TDesC& aName, const TDesC& aValue);

	private:

		// The name, or category, of the meta data.
		HBufC* iName;

		// The value of the meta data.
		HBufC* iValue;
	};

#endif // __CMETADTAENTRY_H
